\name{uht2beta}
\alias{uht2beta}
\alias{beta2uht}
\alias{respgau}
\title{ Gaussian Response Curves and Coefficients }

\description{ The function converts parameters of a Gaussian response curve
  into polynomial linear coefficients, or the reverse. Works for single gradient only. }

\usage{
uht2beta(u, h = NULL, t = NULL)
beta2uht(b0, b1 = NULL, b2 = NULL)
respgau(x, param, uht = TRUE)
}
\arguments{
  \item{u}{ Optimum (location) of the curve. can be a vector of length 3 when
    \code{u}, \code{h} and \code{t} are provided at once. }
  \item{h}{ Expected height of the curve at optimum. }
  \item{t}{ Tolerance (standard deviation of the normal density). }
  \item{b0, b1, b2}{ Regression coefficients for intercept,
    linear term, quadratic term. \code{b0} can be a vector of length 3 when
    \code{b0}, \code{b1} and \code{b2} are provided at once. }
  \item{x}{Vector of predictor values to calculate gaussian response for. }
  \item{param}{Parameters in 'uht' or 'beta' format (see Details). }
  \item{uht}{Logical, if parameters are provided as 'uht' or 'beta' formats
    (see Details). }
}

\details{ \code{uht2beta} is useful for generating Gaussian
  species responses to environmental gradients using 
  the species occurrence/abundance generating functions.
  It converts the 'uht' format to 'beta'.

  \code{beta2uht} does the reverse job.
  It converts the 'beta' format to 'uht'.
  
  \code{respgau} calculates response values for a predictor
  vector given the parameters provided.
}

\value{
  A 3 element vector for regression coefficients:
  first is the intecept, second is for the linear term,
  third is for the squared term.
}
\author{ Peter Solymos }
\examples{
uht2beta(25, 10, 15)
beta2uht(1.5, 0.005, -0.001)
x <- respgau(-50:50, c(25, 10, 15))
y <- respgau(-50:50, c(1.5, 0.005, -0.001), FALSE)
plot(x, type = "l", col = 2)
lines(y, col = 4)
}
\keyword{ datagen }
\keyword{ multivariate }
